## How it works

 * Changelog uses [npmjs.org API](http://search.npmjs.org/) to get the list of versions and the publish dates.
 * It cross-references the versions in `npm` with the commit history from the [Github's API](http://developer.github.com/).


## Inspiration


[Dylan Greene](http://github.com/dylang) built this because he was always curious what was changed when doing `npm update`.
This module's name is inspired by listening to [TheChangelog Podcast](http://thechangelog.com/) on the way to [work](http://opower.com).